body
  font-family 'Marcellus', sans-serif
  background-color #ECECEC
// #sic_from
//   margin-bottom 1em
//   padding 0 1em 0 0
.navbar-excample
  border: 1px solid #d4d4d4;
.nav-tools
  margin-bottom 0em
  .dropdown-toggle
    padding 4px 2em 4px 2em
  nav 
    min-height 25px
    font-size 13px

body 
  section 
    background-color: white;
    padding: 1em;
// #sic_from h3
//   display: inline-block

// #sic_form_details
//   background-color #e4e4e4
//   margin-bottom 1em
//   padding-bottom 1em
//   border-bottom-left-radius 1em
//   border-bottom-right-radius 1em

// .nav-tabs>.active>a, .nav-tabs>.active>a:hover, .nav-tabs>.active>a:focus
//   background-color #ececec

// .tab-content>.tab-pane, .pill-content>.pill-pane
//   background-color #ececec
//   padding 1em
  
// #sicfrom-title 
//   .row
//     padding-left 2em
//     padding-bottom .5em
//     span.add-on
//       width 62px  

// #ubicacionform
//   float left
//   padding-left 2em
  

// #ms-custom-form-header
//   padding: 0px 20px 0
//   margin-bottom: 20px
//   background-color: #f5f5f5
//   border-top: 1px solid #e5e5e5
//   *zoom: 1
//   padding-bottom: 2.5em

// p
//   font-family: 'Arial', serif

// .money-text
//   color: #ffa500

.navbar-inner
  border-radius: 0px

// .navbar-inner_min
//   min-height: 25px
//   font-size: 13px

// .inline_for div
//   display: inline

// .navbar-inner_min > .navbar .nav > li > a
//   padding: 2px 10px 0px 10px

// #breadcrumb
//   font-size: 12px

footer
  text-align: center

// .imagecenter
//   display: block
//   margin-left: auto
//   margin-right: auto

// .ms-form-right-detail
//   padding-bottom: 6px
//   background-color: rgb(255, 255, 255)
//   padding-left: 12px
//   margin-bottom: 5px

// [class^="msicon-"],[class*="msicon-"]
//   display: inline-block
//   width: 30px
//   height: 30px
//   margin-top: 0px
//   *margin-right: 0em
//   line-height: 5px
//   vertical-align: text-top
//   background-image: url("../img/iconos-microsip.png")
//   background-position: 30px 30px
//   background-repeat: no-repeat

// .text-center
//   text-align: center

// .pagecontent
//   background-color: rgba(255, 255, 255, 1)
//   text-align: left
//   padding: 1em
//   padding-top: 1em
//   padding-bottom: 2em

// .table th, .table td
//   padding 0.5em 1.3em 0 1.3em

// .mainmenu
//   text-align: center

.navbar
  margin-bottom -1px

// .autocomplete-light-widget
//   font-size: 14px

// .text-error
//   font-size: 12px


