body {
  font-family: 'Marcellus', sans-serif;
  background-color: #ececec;
}
.navbar-excample {
  border: 1px solid #d4d4d4;
}
.nav-tools {
  margin-bottom: 0em;
}
.nav-tools .dropdown-toggle {
  padding: 4px 2em 4px 2em;
}
.nav-tools nav {
  min-height: 25px;
  font-size: 13px;
}
body section {
  background-color: #fff;
  padding: 1em;
}
.navbar-inner {
  border-radius: 0px;
}
footer {
  text-align: center;
}
.navbar {
  margin-bottom: -1px;
}
