<!-- SERVER ERROR PAGE -->
<!DOCTYPE html>
<html lang='es'>
<head>
  <meta charset='utf-8'>
  <title>{% block title %}Microsip{% endblock %}</title>
  <meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1 maximum-scale=1" />
  <link rel='shortcut icon' href='{{STATIC_URL}}img/logo.ico'>
  <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap.min.css">
  <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap-theme.min.css">
</head>
<body>
<div class="container">
  <div class="row">
    <div class="span12">
      <div class="hero-unit center">
          <h1>:/ Lo sentimos, se ha encontrado un error<small><font face="Tahoma" color="red"> Error 500</font></small></h1>
          <br />
          <br>
          <br>
          <a href="/" class="btn btn-large btn-default"><i class="icon-home icon-white"></i> Regresar a aplicación</a>
        </div>
        <br />
    </div>
  </div>
</div>
</body>
</html>