<!-- MAIN BASE -->
{% extends "base.html" %}
{% block title %}Principal{% endblock %}

<!-- CSS Code -->
{% block style_css %}{% endblock %}
{% block modulestyle_css %}
{% endblock %}
<!-- JavaScript Code -->
{% block js_code %}{% endblock %}
{% block selected_module %} Microsip {% endblock %}
{% block breadcrumb %}{{ block.super }} {% endblock %}

{% block content %}

{% endblock %}