<!-- BASIC BASE -->
<!DOCTYPE html>
<html lang='es'>

<head>
  <meta charset='utf-8'>
  {% block title %}Microsip{% endblock %}
  <meta name="viewport" content="width=device-width, initial-scale=1, minimum-scale=1 maximum-scale=1" />

  <!-- Estilos -->
  <link rel='stylesheet' href='{{STATIC_URL}}css/normalize.css' />
  <!-- Latest compiled and minified CSS -->
  <link href='http://fonts.googleapis.com/css?family=Marcellus' rel='stylesheet' type='text/css'>
  <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap.min.css">
  <link rel="stylesheet" href="//netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap-theme.min.css">
  <link rel="stylesheet" href="{{STATIC_URL}}css/jquery-ui.css">
  <link rel='stylesheet' href='{{STATIC_URL}}css/base.css' />

  {% block style_css %}{% endblock %}
  <link rel='shortcut icon' href='{{STATIC_URL}}img/logo.ico'>
</head>

<body>
  {% if user.is_anonymous %}
  <!-- Si no hay usuario logueado mostrar boton de ingresar -->
  <li id="fat-menu">
    <a href="/login/" class="btn"><i class="glyphicon glyphicon-user"></i> Ingresar</a>
  </li>
  {% endif %}
  <section class='content'>
    <div class="pagecontent">
      {% block content %}{% endblock %}
    </div>
  </section>
  <script src="//ajax.googleapis.com/ajax/libs/jquery/1.11.0/jquery.min.js"></script>
  <!-- // <script src="http://code.jquery.com/jquery-1.11.0.min.js"></script> -->
  <script src="http://code.jquery.com/jquery-migrate-1.2.1.min.js"></script>
  <script src="//netdna.bootstrapcdn.com/bootstrap/3.1.1/js/bootstrap.min.js"></script>
  <!-- <script src="{{ STATIC_URL }}endless_pagination/js/endless-pagination.js"></script> -->
  <script src='{{STATIC_URL}}js/jquery-ui.min.js'></script>
  <script src='{{STATIC_URL}}js/jquery-ui-timepicker.js'></script>

  {% block js_modulecode %}
  {% endblock %}
  {% block js_code %}

  {% endblock %}
</body>

</html>