{% load i18n %}

{% if querystring %}
<tr class="endless_container">
     <td>
          <a class="endless_more" href="{{ path }}{{ querystring }}" rel="{{ querystring_key }}">
                {% if label %}
                     {{ label }}
                {% else %}
                     {% trans "more" %}
                {% endif %}
          </a>
     </td> 
     <td class="endless_loading" style="display: none;">
          {{ loading|safe }}
     </td>
</tr>
{% endif %}