<!-- INDEX PAGE microsip-base -->
{% extends "main/base.html" %}
{% block title %}
Microsip
{% endblock %}

{% block content %}
<div class="row">
	{% for link in menu.items %}
	<!-- Botones de aplicaciones instaladas -->
	<div class="col-sm-4 col-md-2 col-lg-2 ">
		<p class="text-center">
			<a href="{{ link.url }}" class='btn btn-default'><i class="{{ link.icon_class }}"></i> {{ link.name }}</a>
		</p>
	</div>
	{% endfor %}
</div>
{% endblock %}