echo off
color 7F
cls
echo 			==================================
echo 			=                                =
echo 			=     SERVIDOR DE PAGINA WEB     =
echo 			=                                =
echo 			=     MODO: PRUEBAS    	         =
echo 			=     POR FAVOR NO CERRAR!!!!    =
echo 			=                                =
echo 			==================================
echo.
echo.


python manage_dev.py celeryd
